@@ -26,9 +26,9 @@ It is used to delegate rendering to real objects but keeping config in place
 from __future__ import division
 import io
 import sys
-from pygal.config import Config
 from pygal._compat import u, is_list_like
 from pygal.graph import CHARTS_NAMES
+from pygal.config import Config, CONFIG_ITEMS
 from pygal.util import prepare_values
 from uuid import uuid4
 
@@ -73,63 +73,86 @@ class Ghost(object):
         self.raw_series2 = []
         self.xml_filters = []
 
-    def add(self, title, values, secondary=False):
+    def add(self, title, values, **kwargs):
         """Add a serie to this graph"""
         if not is_list_like(values) and not isinstance(values, dict):
             values = [values]
-        if secondary:
-            self.raw_series2.append((title, values))
+        if kwargs.get('secondary', False):
+            self.raw_series2.append((title, values, kwargs))
         else:
-            self.raw_series.append((title, values))
+            self.raw_series.append((title, values, kwargs))
 
     def add_xml_filter(self, callback):
         self.xml_filters.append(callback)
 
-    def make_series(self, series):
-        return prepare_values(series, self.config, self.cls)
+    def make_series(self, series, offset=0):
+        return prepare_values(series, self.config, self.cls, offset)
+
+    def make_instance(self, overrides=None):
+        for conf_key in CONFIG_ITEMS:
+            if conf_key.is_list:
+                if getattr(self, conf_key.name, None):
+                    setattr(self, conf_key.name,
+                            list(getattr(self, conf_key.name)))
 
-    def make_instance(self, overrides={}):
         self.config(**self.__dict__)
-        self.config.__dict__.update(overrides)
+        self.config.__dict__.update(overrides or {})
         series = self.make_series(self.raw_series)
-        secondary_series = self.make_series(self.raw_series2)
+        secondary_series = self.make_series(
+            self.raw_series2, len(series or []))
         self._last__inst = self.cls(
             self.config, series, secondary_series, self.uuid,
             self.xml_filters)
         return self._last__inst
 
     # Rendering
-    def render(self, is_unicode=False):
-        return self.make_instance().render(is_unicode=is_unicode)
+    def render(self, is_unicode=False, **kwargs):
+        return (self
+                .make_instance(overrides=kwargs)
+                .render(is_unicode=is_unicode))
 
-    def render_tree(self):
-        return self.make_instance().render_tree()
+    def render_tree(self, **kwargs):
+        return self.make_instance(overrides=kwargs).render_tree()
+
+    def render_table(self, **kwargs):
+        # Import here to avoid lxml import
+        try:
+            from pygal.table import Table
+        except ImportError:
+            raise ImportError('You must install lxml to use render table')
+        real_cls, self.cls = self.cls, Table
+        rv = self.make_instance().render(**kwargs)
+        self.cls = real_cls
+        return rv
 
     def render_pyquery(self):
         """Render the graph, and return a pyquery wrapped tree"""
         from pyquery import PyQuery as pq
-        return pq(self.render_tree())
+        return pq(self.render(), parser='html')
 
-    def render_in_browser(self):
+    def render_in_browser(self, **kwargs):
         """Render the graph, open it in your browser with black magic"""
-        from lxml.html import open_in_browser
-        open_in_browser(self.render_tree(), encoding='utf-8')
+        try:
+            from lxml.html import open_in_browser
+        except ImportError:
+            raise ImportError('You must install lxml to use render in browser')
+        open_in_browser(self.render_tree(**kwargs), encoding='utf-8')
 
-    def render_response(self):
+    def render_response(self, **kwargs):
         """Render the graph, and return a Flask response"""
         from flask import Response
-        return Response(self.render(), mimetype='image/svg+xml')
+        return Response(self.render(**kwargs), mimetype='image/svg+xml')
 
-    def render_to_file(self, filename):
+    def render_to_file(self, filename, **kwargs):
         """Render the graph, and write it to filename"""
         with io.open(filename, 'w', encoding='utf-8') as f:
-            f.write(self.render(is_unicode=True))
+            f.write(self.render(is_unicode=True, **kwargs))
 
-    def render_to_png(self, filename=None, dpi=72):
+    def render_to_png(self, filename=None, dpi=72, **kwargs):
         """Render the graph, convert it to png and write it to filename"""
         import cairosvg
         return cairosvg.svg2png(
-            bytestring=self.render(), write_to=filename, dpi=dpi)
+            bytestring=self.render(**kwargs), write_to=filename, dpi=dpi)
 
     def render_sparktext(self, relative_to=None):
         """Make a mini text sparkline from chart"""
@@ -171,6 +194,10 @@ class Ghost(object):
         spark_options.update(kwargs)
         return self.make_instance(spark_options).render()
 
+    def _repr_svg_(self):
+        """Display svg in IPython notebook"""
+        return self.render(disable_xml_declaration=True)
+
     def _repr_png_(self):
         """Display png in IPython notebook"""
         return self.render_to_png()
