@@ -36,20 +36,19 @@ class Bar(Graph):
         self._x_ranges = None
         super(Bar, self).__init__(*args, **kwargs)
 
-    def _bar(self, parent, x, y, index, i, zero, shift=True, secondary=False):
+    def _bar(self, serie, parent, x, y, i, zero, secondary=False):
         width = (self.view.x(1) - self.view.x(0)) / self._len
         x, y = self.view((x, y))
         series_margin = width * self._series_margin
         x += series_margin
         width -= 2 * series_margin
-        if shift:
-            width /= self._order
-            x += index * width
-            serie_margin = width * self._serie_margin
-            x += serie_margin
-            width -= 2 * serie_margin
+        width /= self._order
+        x += serie.index * width
+        serie_margin = width * self._serie_margin
+        x += serie_margin
+        width -= 2 * serie_margin
         height = self.view.y(zero) - y
-        r = self.rounded_bars * 1 if self.rounded_bars else 0
+        r = serie.rounded_bars * 1 if serie.rounded_bars else 0
         self.svg.transposable_node(
             parent, 'rect',
             x=x, y=y, rx=r, ry=r, width=width, height=height,
@@ -57,8 +56,9 @@ class Bar(Graph):
         transpose = swap if self.horizontal else ident
         return transpose((x + width / 2, y + height / 2))
 
-    def bar(self, serie_node, serie, index, rescale=False):
+    def bar(self, serie, rescale=False):
         """Draw a bar graph for a serie"""
+        serie_node = self.svg.serie(serie)
         bars = self.svg.node(serie_node['plot'], class_="bars")
         if rescale and self.secondary_series:
             points = [
@@ -79,7 +79,7 @@ class Bar(Graph):
             val = self._format(serie.values[i])
 
             x_center, y_center = self._bar(
-                bar, x, y, index, i, self.zero, secondary=rescale)
+                serie, bar, x, y, i, self.zero, secondary=rescale)
             self._tooltip_data(
                 bar, val, x_center, y_center, classes="centered")
             self._static_value(serie_node, val, x_center, y_center)
@@ -113,12 +113,10 @@ class Bar(Graph):
             min_0_ratio = (self.zero - self._box.ymin) / self._box.height or 1
             max_0_ratio = (self._box.ymax - self.zero) / self._box.height or 1
 
-            new_ymax = (self.zero - ymin) * (1 / min_0_ratio - 1)
-            new_ymin = -(ymax - self.zero) * (1 / max_0_ratio - 1)
             if ymax > self._box.ymax:
-                ymin = new_ymin
+                ymin = -(ymax - self.zero) * (1 / max_0_ratio - 1)
             else:
-                ymax = new_ymax
+                ymax = (self.zero - ymin) * (1 / min_0_ratio - 1)
 
             left_range = abs(self._box.ymax - self._box.ymin)
             right_range = abs(ymax - ymin) or 1
@@ -131,7 +129,7 @@ class Bar(Graph):
                 for y in y_pos]
 
     def _plot(self):
-        for index, serie in enumerate(self.series):
-            self.bar(self._serie(index), serie, index)
-        for index, serie in enumerate(self.secondary_series, len(self.series)):
-            self.bar(self._serie(index), serie, index, True)
+        for serie in self.series:
+            self.bar(serie)
+        for serie in self.secondary_series:
+            self.bar(serie, True)
