@@ -26,7 +26,7 @@ from pygal.view import Margin, Box
 from pygal.util import (
     get_text_box, get_texts_box, cut, rad, humanize, truncate, split_title)
 from pygal.svg import Svg
-from pygal.util import cached_property
+from pygal.util import cached_property, majorize
 from math import sin, cos, sqrt
 
 
@@ -55,9 +55,8 @@ class BaseGraph(object):
         self.view = None
         if self.logarithmic and self.zero == 0:
             # Explicit min to avoid interpolation dependency
-            from pygal.graph.xy import XY
-            if isinstance(self, XY):
-                get = lambda x: x[1]
+            if self._dual:
+                get = lambda x: x[1] or 1
             else:
                 get = lambda x: x
 
@@ -66,7 +65,7 @@ class BaseGraph(object):
                 [get(val)
                  for serie in self.series for val in serie.safe_values]))
 
-            self.zero = min(positive_values) if positive_values else 0
+            self.zero = min(positive_values or 1,) or 1
         self._draw()
         self.svg.pre_render()
 
@@ -83,9 +82,6 @@ class BaseGraph(object):
     def _compute(self):
         """Initial computations to draw the graph"""
 
-    def _plot(self):
-        """Actual plotting of the graph"""
-
     def _compute_margin(self):
         """Compute graph margins from set texts"""
         self._legend_at_left_width = 0
@@ -203,31 +199,76 @@ class BaseGraph(object):
     def _secondary_min(self):
         """Getter for the minimum series value"""
         return (self.range[0] if (self.range and self.range[0] is not None)
-            else (min(self._secondary_values) if self._secondary_values else None))
+                else (min(self._secondary_values)
+                      if self._secondary_values else None))
 
     @cached_property
     def _min(self):
         """Getter for the minimum series value"""
-        return (self.range[0] if (self.range and self.range[0] is not None) 
-            else (min(self._values) if self._values else None))
+        return (self.range[0] if (self.range and self.range[0] is not None)
+                else (min(self._values)
+                      if self._values else None))
 
     @cached_property
     def _max(self):
         """Getter for the maximum series value"""
         return (self.range[1] if (self.range and self.range[1] is not None)
-            else (max(self._values) if self._values else None))
+                else (max(self._values) if self._values else None))
 
     @cached_property
     def _secondary_max(self):
         """Getter for the maximum series value"""
         return (self.range[1] if (self.range and self.range[1] is not None)
-            else (max(self._secondary_values) if self._secondary_values else None))
+                else (max(self._secondary_values)
+                      if self._secondary_values else None))
 
     @cached_property
     def _order(self):
         """Getter for the number of series"""
         return len(self.all_series)
 
+    @cached_property
+    def _x_major_labels(self):
+        """Getter for the x major label"""
+        if self.x_labels_major:
+            return self.x_labels_major
+        if self.x_labels_major_every:
+            return [self._x_labels[i][0] for i in range(
+                0, len(self._x_labels), self.x_labels_major_every)]
+        if self.x_labels_major_count:
+            label_count = len(self._x_labels)
+            major_count = self.x_labels_major_count
+            if (major_count >= label_count):
+                return [label[0] for label in self._x_labels]
+
+            return [self._x_labels[
+                    int(i * (label_count - 1) / (major_count - 1))][0]
+                    for i in range(major_count)]
+
+        return []
+
+    @cached_property
+    def _y_major_labels(self):
+        """Getter for the y major label"""
+        if self.y_labels_major:
+            return self.y_labels_major
+        if self.y_labels_major_every:
+            return [self._y_labels[i][1] for i in range(
+                0, len(self._y_labels), self.y_labels_major_every)]
+        if self.y_labels_major_count:
+            label_count = len(self._y_labels)
+            major_count = self.y_labels_major_count
+            if (major_count >= label_count):
+                return [label[1] for label in self._y_labels]
+
+            return [self._y_labels[
+                int(i * (label_count - 1) / (major_count - 1))][1]
+                for i in range(major_count)]
+
+        return majorize(
+            cut(self._y_labels, 1)
+        )
+
     def _draw(self):
         """Draw all the things"""
         self._compute()
@@ -252,7 +293,7 @@ class BaseGraph(object):
             is_unicode=is_unicode, pretty_print=self.pretty_print)
 
     def render_tree(self):
-        """Render the graph, and return lxml tree"""
+        """Render the graph, and return (l)xml etree"""
         svg = self.svg.root
         for f in self.xml_filters:
             svg = f(svg)
