@@ -53,12 +53,22 @@ class Line(Graph):
     def _fill(self, values):
         """Add extra values to fill the line"""
         zero = self.view.y(min(max(self.zero, self._box.ymin), self._box.ymax))
+
+        # Check to see if the data has been padded with "none's"
+        # Fill doesn't work correctly otherwise
+        end = -1
+        for i, (x, y) in enumerate(reversed(values)):
+            if x is not None:
+                end = -1 - i
+                break
+
         return ([(values[0][0], zero)] +
                 values +
-                [(values[-1][0], zero)])
+                [(values[end][0], zero)])
 
-    def line(self, serie_node, serie, rescale=False):
+    def line(self, serie, rescale=False):
         """Draw the line serie"""
+        serie_node = self.svg.serie(serie)
         if rescale and self.secondary_series:
             points = [
                 (x, self._scale_diff + (y - self._scale_min_2nd) * self._scale)
@@ -66,31 +76,15 @@ class Line(Graph):
         else:
             points = serie.points
         view_values = list(map(self.view, points))
-        if self.show_dots:
-            if self.show_only_major_dots:
-                major_dots_index = []
-                if self.x_labels:
-                    if self.x_labels_major:
-                        major_dots_index = []
-                        for major in self.x_labels_major:
-                            start = -1
-                            while True:
-                                try:
-                                    index = self.x_labels.index(
-                                        major, start + 1)
-                                except ValueError:
-                                    break
-                                else:
-                                    major_dots_index.append(index)
-                                    start = index
-                    elif self.x_labels_major_every:
-                        major_dots_index = range(
-                            0, len(self.x_labels), self.x_labels_major_every)
-
+        if serie.show_dots:
             for i, (x, y) in enumerate(view_values):
-                if None in (x, y) or (self.show_only_major_dots
-                                      and i not in major_dots_index):
+                if None in (x, y):
                     continue
+                if (serie.show_only_major_dots and
+                        self.x_labels and i < len(self.x_labels) and
+                        self.x_labels[i] not in self._x_major_labels):
+                    continue
+
                 metadata = serie.metadata.get(i)
                 classes = []
                 if x > self.view.width / 2:
@@ -103,7 +97,7 @@ class Line(Graph):
                     self.svg.node(serie_node['overlay'], class_="dots"),
                     metadata)
                 val = self._get_value(serie.points, i)
-                self.svg.node(dots, 'circle', cx=x, cy=y, r=self.dots_size,
+                self.svg.node(dots, 'circle', cx=x, cy=y, r=serie.dots_size,
                               class_='dot reactive tooltip-trigger')
                 self._tooltip_data(
                     dots, val, x, y)
@@ -112,14 +106,14 @@ class Line(Graph):
                     x + self.value_font_size,
                     y + self.value_font_size)
 
-        if self.stroke:
+        if serie.stroke:
             if self.interpolate:
                 view_values = list(map(self.view, serie.interpolated))
-            if self.fill:
+            if serie.fill:
                 view_values = self._fill(view_values)
             self.svg.line(
                 serie_node['plot'], view_values, close=self._self_close,
-                class_='line reactive' + (' nofill' if not self.fill else ''))
+                class_='line reactive' + (' nofill' if not serie.fill else ''))
 
     def _compute(self):
         # X Labels
@@ -142,7 +136,7 @@ class Line(Graph):
             self._x_labels = None
 
         if self.include_x_axis:
-        # Y Label
+            # Y Label
             self._box.ymin = min(self._min or 0, 0)
             self._box.ymax = max(self._max or 0, 0)
         else:
@@ -156,8 +150,8 @@ class Line(Graph):
         self._y_labels = list(zip(map(self._format, y_pos), y_pos))
 
     def _plot(self):
-        for index, serie in enumerate(self.series):
-            self.line(self._serie(index), serie)
+        for serie in self.series:
+            self.line(serie)
 
-        for index, serie in enumerate(self.secondary_series, len(self.series)):
-            self.line(self._serie(index), serie, True)
+        for serie in self.secondary_series:
+            self.line(serie, True)
