@@ -16,14 +16,15 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
+
 from pygal import (
-    Line, Dot, Pie, Radar, Config, Bar, Funnel, Worldmap,
-    SupranationalWorldmap, Histogram, Gauge, Box,
+    Line, Dot, Pie, Treemap, Radar, Config, Bar, Funnel, Worldmap,
+    SupranationalWorldmap, Histogram, Gauge, Box, XY,
+    Pyramid, DateY, HorizontalBar, HorizontalStackedBar,
     FrenchMap_Regions, FrenchMap_Departments)
 from pygal._compat import u
 from pygal.test.utils import texts
-from pygal.test import pytest_generate_tests, make_data
-from uuid import uuid4
+from tempfile import NamedTemporaryFile
 
 
 def test_config_behaviours():
@@ -271,7 +272,7 @@ def test_no_data():
 
 def test_include_x_axis(Chart):
     chart = Chart()
-    if Chart in (Pie, Radar, Funnel, Dot, Gauge, Worldmap,
+    if Chart in (Pie, Treemap, Radar, Funnel, Dot, Gauge, Worldmap,
                  SupranationalWorldmap, Histogram, Box,
                  FrenchMap_Regions, FrenchMap_Departments):
         return
@@ -295,17 +296,17 @@ def test_include_x_axis(Chart):
 
 def test_css(Chart):
     css = "{{ id }}text { fill: #bedead; }\n"
-    css_file = '/tmp/pygal_custom_style-%s.css' % uuid4()
-    with open(css_file, 'w') as f:
+    with NamedTemporaryFile('w') as f:
         f.write(css)
+        f.flush()
 
-    config = Config()
-    config.css.append(css_file)
+        config = Config()
+        config.css.append(f.name)
 
-    chart = Chart(config)
-    chart.add('/', [10, 1, 5])
-    svg = chart.render().decode('utf-8')
-    assert '#bedead' in svg
+        chart = Chart(config)
+        chart.add('/', [10, 1, 5])
+        svg = chart.render().decode('utf-8')
+        assert '#bedead' in svg
 
 
 def test_inline_css(Chart):
@@ -322,3 +323,142 @@ def test_inline_css(Chart):
 def test_meta_config():
     from pygal.config import CONFIG_ITEMS
     assert all(c.name != 'Unbound' for c in CONFIG_ITEMS)
+
+
+def test_label_rotation(Chart):
+    chart = Chart(x_label_rotation=28, y_label_rotation=76)
+    chart.add('1', [4, -5, 123, 59, 38])
+    chart.add('2', [89, 0, 8, .12, 8])
+    chart.x_labels = ['one', 'twoooooooooooooooooooooo', 'three', '4']
+    q = chart.render_pyquery()
+    if Chart in (Line, Bar):
+        assert len(q('.axis.x text[transform^="rotate(28"]')) == 4
+        assert len(q('.axis.y text[transform^="rotate(76"]')) == 13
+
+
+def test_legend_at_bottom(Chart):
+    chart = Chart(legend_at_bottom=True)
+    chart.add('1', [4, -5, 123, 59, 38])
+    chart.add('2', [89, 0, 8, .12, 8])
+    chart.x_labels = ['one', 'twoooooooooooooooooooooo', 'three', '4']
+    lab = chart.render()
+    chart.legend_at_bottom = False
+    assert lab != chart.render()
+
+
+def test_x_y_title(Chart):
+    chart = Chart(title='I Am A Title',
+                  x_title="I am a x title",
+                  y_title="I am a y title")
+    chart.add('1', [4, -5, 123, 59, 38])
+    chart.add('2', [89, 0, 8, .12, 8])
+    chart.x_labels = ['one', 'twoooooooooooooooooooooo', 'three', '4']
+    q = chart.render_pyquery()
+    assert len(q('.titles .title')) == 3
+
+
+def test_x_label_major(Chart):
+    if Chart in (
+            Pie, Treemap, Funnel, Dot, Gauge, Worldmap,
+            SupranationalWorldmap, Histogram, Box,
+            FrenchMap_Regions, FrenchMap_Departments,
+            Pyramid, DateY):
+        return
+    chart = Chart()
+    chart.add('test', range(12))
+    chart.x_labels = map(str, range(12))
+
+    q = chart.render_pyquery()
+    assert len(q(".axis.x text.major")) == 0
+
+    chart.x_labels_major = ['1', '5', '11', '1.0', '5.0', '11.0']
+    q = chart.render_pyquery()
+    assert len(q(".axis.x text.major")) == 3
+    assert len(q(".axis.x text")) == 12
+
+    chart.show_minor_x_labels = False
+    q = chart.render_pyquery()
+    assert len(q(".axis.x text.major")) == 3
+    assert len(q(".axis.x text")) == 3
+
+    chart.show_minor_x_labels = True
+    chart.x_labels_major = None
+    chart.x_labels_major_every = 2
+    q = chart.render_pyquery()
+    assert len(q(".axis.x text.major")) == 6
+    assert len(q(".axis.x text")) == 12
+
+    chart.x_labels_major_every = None
+    chart.x_labels_major_count = 4
+    q = chart.render_pyquery()
+    assert len(q(".axis.x text.major")) == 4
+    assert len(q(".axis.x text")) == 12
+
+    chart.x_labels_major_every = None
+    chart.x_labels_major_count = 78
+    q = chart.render_pyquery()
+    assert len(q(".axis.x text.major")) == 12
+    assert len(q(".axis.x text")) == 12
+
+
+def test_y_label_major(Chart):
+    if Chart in (
+            Pie, Treemap, Funnel, Dot, Gauge, Worldmap,
+            SupranationalWorldmap, Histogram, Box,
+            FrenchMap_Regions, FrenchMap_Departments,
+            HorizontalBar, HorizontalStackedBar,
+            Pyramid, DateY):
+        return
+    chart = Chart()
+    data = range(12)
+    if Chart == XY:
+        data = list(zip(*[range(12), range(12)]))
+    chart.add('test', data)
+    chart.y_labels = range(12)
+
+    q = chart.render_pyquery()
+    assert len(q(".axis.y text.major")) == 3
+
+    chart.y_labels_major = [1.0, 5.0, 11.0]
+    q = chart.render_pyquery()
+    assert len(q(".axis.y text.major")) == 3
+    assert len(q(".axis.y text")) == 12
+
+    chart.show_minor_y_labels = False
+    q = chart.render_pyquery()
+    assert len(q(".axis.y text.major")) == 3
+    assert len(q(".axis.y text")) == 3
+
+    chart.show_minor_y_labels = True
+    chart.y_labels_major = None
+    chart.y_labels_major_every = 2
+    q = chart.render_pyquery()
+    assert len(q(".axis.y text.major")) == 6
+    assert len(q(".axis.y text")) == 12
+
+    chart.y_labels_major_every = None
+    chart.y_labels_major_count = 4
+    q = chart.render_pyquery()
+    assert len(q(".axis.y text.major")) == 4
+    assert len(q(".axis.y text")) == 12
+
+    chart.y_labels_major_every = None
+    chart.y_labels_major_count = 78
+    q = chart.render_pyquery()
+    assert len(q(".axis.y text.major")) == 12
+    assert len(q(".axis.y text")) == 12
+
+
+def test_no_y_labels(Chart):
+    chart = Chart()
+    chart.y_labels = []
+    chart.add('_', [1, 2, 3])
+    chart.add('?', [10, 21, 5])
+    assert chart.render_pyquery()
+
+
+def test_fill(Chart):
+    chart = Chart(fill=True)
+    chart.add('_', [1, 2, 3])
+    chart.add('?', [10, 21, 5])
+    assert chart.render_pyquery()
