@@ -16,20 +16,29 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
+
 import os
 import pygal
 import uuid
 import sys
+import pytest
 from pygal import i18n
 from pygal.graph.frenchmap import DEPARTMENTS, REGIONS
 from pygal.util import cut
 from pygal._compat import u
-from pygal.test import pytest_generate_tests, make_data
+from pygal.test import make_data
+
+try:
+    import cairosvg
+except ImportError:
+    cairosvg = None
 
 
 def test_multi_render(Chart, datas):
     chart = Chart()
     chart = make_data(chart, datas)
+    chart.x_labels = (str(a) for a in 'labels')
+    chart.y_labels = (str(a) for a in range(6))
     svg = chart.render()
     for i in range(2):
         assert svg == chart.render()
@@ -48,12 +57,8 @@ def test_render_to_file(Chart, datas):
     os.remove(file_name)
 
 
+@pytest.mark.skipif(not cairosvg, reason="CairoSVG not installed")
 def test_render_to_png(Chart, datas):
-    try:
-        import cairosvg
-    except ImportError:
-        return
-
     file_name = '/tmp/test_graph-%s.png' % uuid.uuid4()
     if os.path.exists(file_name):
         os.remove(file_name)
@@ -61,8 +66,10 @@ def test_render_to_png(Chart, datas):
     chart = Chart()
     chart = make_data(chart, datas)
     chart.render_to_png(file_name)
+    png = chart._repr_png_()
+
     with open(file_name, 'rb') as f:
-        assert f.read()
+        assert png == f.read()
     os.remove(file_name)
 
 
@@ -98,7 +105,7 @@ def test_metadata(Chart):
             'Five', 'http://7.example.com/', 'Seven'):
         assert md in cut(q('desc'), 'text')
 
-    if Chart == pygal.Pie:
+    if Chart in (pygal.Pie, pygal.Treemap):
         # Slices with value 0 are not rendered
         assert len(v) - 1 == len(q('.tooltip-trigger').siblings('.value'))
     elif Chart not in (
@@ -352,3 +359,37 @@ def test_labels_with_links(Chart):
         assert len(links) == 4  # 3 links and 1 tooltip
     else:
         assert len(links) == 8  # 7 links and 1 tooltip
+
+
+def test_sparkline(Chart, datas):
+    chart = Chart()
+    chart = make_data(chart, datas)
+    assert chart.render_sparkline()
+
+
+def test_secondary(Chart):
+    chart = Chart()
+    rng = [83, .12, -34, 59]
+    chart.add('First serie', rng)
+    chart.add('Secondary serie',
+              map(lambda x: x * 2, rng),
+              secondary=True)
+    assert chart.render_pyquery()
+
+
+def test_ipython_notebook(Chart, datas):
+    chart = Chart()
+    chart = make_data(chart, datas)
+    assert chart._repr_svg_()
+
+
+def test_long_title(Chart, datas):
+    chart = Chart(
+        title="A chart is a graphical representation of data, in which "
+        "'the data is represented by symbols, such as bars in a bar chart, "
+        "lines in a line chart, or slices in a pie chart'. A chart can "
+        "represent tabular numeric data, functions or some kinds of "
+        "qualitative structure and provides different info.")
+    chart = make_data(chart, datas)
+    q = chart.render_pyquery()
+    assert len(q('.titles text')) == 5
